from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean

Fastx36_V0_1_0 = CommandToolBuilder(tool="fastx36", base_command=["fastx36"], inputs=[ToolInput(tag="in_compare_forward_strand", input_type=Boolean(optional=True), prefix="-3", doc=InputDocumentation(doc="compare forward strand only")), ToolInput(tag="in_high_scores_reported", input_type=Boolean(optional=True), prefix="-b", doc=InputDocumentation(doc=":  high scores reported (limited by -E by default);\n=<int> forces <int> results;")), ToolInput(tag="in_expected_fraction_joining", input_type=Boolean(optional=True), prefix="-c", doc=InputDocumentation(doc=":  expected fraction for band-optimization, joining")), ToolInput(tag="in_length_querysbjct_name", input_type=Boolean(optional=True), prefix="-C", doc=InputDocumentation(doc=":  length of the query/sbjct name in alignments")), ToolInput(tag="in_number_alignments_shown", input_type=Boolean(optional=True), prefix="-d", doc=InputDocumentation(doc=":  number of alignments shown (limited by -E by default)")), ToolInput(tag="in_enable_debugging_output", input_type=Boolean(optional=True), prefix="-D", doc=InputDocumentation(doc="enable debugging output")), ToolInput(tag="in_expandscript_extend_hits", input_type=Boolean(optional=True), prefix="-e", doc=InputDocumentation(doc=":  expand_script to extend hits")), ToolInput(tag="in__evalueerepeat_threshold", input_type=Boolean(optional=True), prefix="-E", doc=InputDocumentation(doc=":  E()-value,E()-repeat threshold")), ToolInput(tag="in__gapopen_penalty", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc=":  gap-open penalty")), ToolInput(tag="in_min_evalue_displayed", input_type=Boolean(optional=True), prefix="-F", doc=InputDocumentation(doc=":  min E()-value displayed")), ToolInput(tag="in__gapextension_penalty", input_type=Boolean(optional=True), prefix="-g", doc=InputDocumentation(doc=":  gap-extension penalty")), ToolInput(tag="in_show_histogram", input_type=Boolean(optional=True), prefix="-H", doc=InputDocumentation(doc="show histogram")), ToolInput(tag="in_search_with_reversecomplement", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="search with reverse-complement")), ToolInput(tag="in_interactive_mode", input_type=Boolean(optional=True), prefix="-I", doc=InputDocumentation(doc="interactive mode")), ToolInput(tag="in__frameshift_penalty", input_type=Boolean(optional=True), prefix="-j", doc=InputDocumentation(doc=":  frame-shift penalty")), ToolInput(tag="in__number_shuffles", input_type=Boolean(optional=True), prefix="-k", doc=InputDocumentation(doc=":  number of shuffles")), ToolInput(tag="in_fastlibs_abbreviation_file", input_type=Boolean(optional=True), prefix="-l", doc=InputDocumentation(doc=":  FASTLIBS abbreviation file")), ToolInput(tag="in_long_library_descriptions", input_type=Boolean(optional=True), prefix="-L", doc=InputDocumentation(doc="long library descriptions")), ToolInput(tag="in_outputalignment_format_entries", input_type=Boolean(optional=True), prefix="-m", doc=InputDocumentation(doc=":  Output/alignment format;\n0 - standard ':. ' alignment; 1 - ' xX'; 2 - '.MS..'; 3 - separate >fasta entries;\n4 - '---' alignment map; 5 - 0+4; 6 - <html>;\n8 - BLAST tabular; 8C commented BLAST tabular; 8CC BLAST tab CIGAR, 8CD BLAST tab CIGAR ext; 8CB BLAST tab BTOP\nB - BLAST Query/Sbjct alignments; BB - complete BLAST output;\n9 - FASTA tabular; 9c - FASTA tabular encoded; 9C FASTA tabular CIGAR encoded; 9B FASTA tabular BTOP encoded\n10 - parseable key:value; 11 - lav for LALIGN;\nA - aligned residue score\nF - 'F0,6,9c out_file' - alternate output formats to files;")), ToolInput(tag="in_filter_library_sequence", input_type=Boolean(optional=True), prefix="-M", doc=InputDocumentation(doc=":  filter on library sequence length")), ToolInput(tag="in_dnarna_query", input_type=Boolean(optional=True), prefix="-n", doc=InputDocumentation(doc="DNA/RNA query")), ToolInput(tag="in_max_library_length", input_type=Boolean(optional=True), prefix="-N", doc=InputDocumentation(doc=":  max library length before overlapping")), ToolInput(tag="in_offset_coordinates_querysubject", input_type=Boolean(optional=True), prefix="-o", doc=InputDocumentation(doc=":  offset coordinates of query/subject")), ToolInput(tag="in_write_results_file", input_type=Boolean(optional=True), prefix="-O", doc=InputDocumentation(doc=":  write results to file")), ToolInput(tag="in_protein_query", input_type=Boolean(optional=True), prefix="-p", doc=InputDocumentation(doc="protein query")), ToolInput(tag="in_var_25", input_type=Boolean(optional=True), prefix="-q", doc=InputDocumentation(doc="quiet [default] -- do not prompt")), ToolInput(tag="in_var_26", input_type=Boolean(optional=True), prefix="-Q", doc=InputDocumentation(doc="quiet [default] -- do not prompt")), ToolInput(tag="in__matchmismatch_dnarna", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc=":  [+0/0]  +match/-mismatch for DNA/RNA")), ToolInput(tag="in_raw_score_file", input_type=Boolean(optional=True), prefix="-R", doc=InputDocumentation(doc=":  raw score file")), ToolInput(tag="in_scoring_matrix_proteinbl", input_type=Boolean(optional=True), prefix="-s", doc=InputDocumentation(doc=":  Scoring matrix: (protein)\nBL50, BP62 (sets -f -11 -g -1); P250, OPT5, VT200,\nVT160, P120, VT120, BL80, VT80, MD40, VT40, MD20, VT20, MD10, VT10;\nscoring matrix file name; -s ?BL50 adjusts matrix for short queries;")), ToolInput(tag="in_filter_lowercase_seg", input_type=Boolean(optional=True), prefix="-S", doc=InputDocumentation(doc="filter lowercase (seg) residues")), ToolInput(tag="in_translation_genetic_code", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc=":  translation genetic code")), ToolInput(tag="in__max_threadsworkers", input_type=Boolean(optional=True), prefix="-T", doc=InputDocumentation(doc=":  max threads/workers")), ToolInput(tag="in_rna_query", input_type=Boolean(optional=True), prefix="-U", doc=InputDocumentation(doc="RNA query")), ToolInput(tag="in_shuffle_window_size", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc=":  shuffle window size")), ToolInput(tag="in_annotation_characters_querylibrary", input_type=Boolean(optional=True), prefix="-V", doc=InputDocumentation(doc=":  annotation characters in query/library for aligments")), ToolInput(tag="in_width_alignment_display", input_type=Boolean(optional=True), prefix="-w", doc=InputDocumentation(doc=":  width of alignment display")), ToolInput(tag="in__extended_options", input_type=Boolean(optional=True), prefix="-X", doc=InputDocumentation(doc=":  Extended options")), ToolInput(tag="in_statistics_estimation_method", input_type=Boolean(optional=True), prefix="-z", doc=InputDocumentation(doc=":  Statistics estimation method:\n1 - regression; -1 - no stats.; 0 - no scaling; 2 - Maximum Likelihood Est.;\n3 - Altschul/Gish; 4 - iter. regress.; 5 - regress w/variance;\n6 - MLE with comp. adj.;\n11 - 16 - estimates from shuffled library sequences;\n21 - 26 - E2()-stats from shuffled high-scoring sequences;")), ToolInput(tag="in_database_size_evalue", input_type=Boolean(optional=True), prefix="-Z", doc=InputDocumentation(doc=":  [library entries] database size for E()-value"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Fastx36_V0_1_0().translate("wdl", allow_empty_container=True)

